// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"fmt"
	"os"

	"github.com/spf13/cobra"
)

var accountRenewAPIKeyCmd = &cobra.Command{
	Use:   "renew-apikey <identifier>",
	Short: "Renew the APIKey of an account",
	Run: func(cmd *cobra.Command, args []string) {
		if len(args) != 1 {
			if err := cmd.Usage(); err != nil {
				Logger.Error().Msgf("Failed to print usage: %s", err)
			}
			os.Exit(1)
		}
		os.Exit(accountRenewAPIKey(args[0]))
	},
}

func accountRenewAPIKey(identifier string) int {
	conn, err := GetClient(false)
	if err != nil {
		Logger.Error().Msgf("Cannot connect to the NATS server: %s", err)
		return 1
	}

	account, err := conn.AccountFind(identifier)
	if err != nil {
		Logger.Error().Msgf("Could not find account %s: %s", identifier, err)
		return 1
	}

	account, err = conn.AccountRenewAPIKey(account.GetIDAsUUID())
	if err != nil {
		Logger.Error().Msgf("Error renewing the account: %s", err)
		return 1
	}

	fmt.Printf("New API Key:\n%s\n", account.ApiKey)

	return 0
}

func init() {
	accountCmd.AddCommand(accountRenewAPIKeyCmd)
}
