// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"context"
	"os"

	"github.com/spf13/cobra"
	"xbus.io/go-xbus/v4/api/control"
)

var debugCmd = cobra.Command{
	Use:   "debug",
	Short: "Server Debug Utilities",
}

var debugInfoCmd = cobra.Command{
	Use:   "info <entry> [ arg [ arg [...] ] ]",
	Short: "Show debug info",
	Run: func(cmd *cobra.Command, args []string) {
		if len(args) == 0 {
			usage(cmd)
		}
		infoEntry := args[0]
		if len(args) > 1 {
			args = args[1:]
		} else {
			args = nil
		}

		ctx, cancel := contextCancelOnSignal(
			context.Background(), os.Interrupt,
		)
		defer cancel()

		c, err := GetClient(false)
		if err != nil {

			Logger.Fatal().Err(err).Msg("could not get debug info")
		}
		if err := c.Control.Debug.Info(ctx, &control.DebugInfoRequest{
			Entry:  infoEntry,
			Args:   args,
			Format: "text",
		}, func(_ context.Context, chunks *control.OctetStreamList) {
			for _, chunk := range chunks.Chunks {
				if _, err := os.Stdout.Write(chunk.Data); err != nil {
					Logger.Err(err).Msg("could not get debug info")
					cancel()
				}
			}
		}); err != nil {
			Logger.Fatal().Err(err).Msg("could not get debug info")
		}
	},
}

func init() {
	RootCmd.AddCommand(&debugCmd)

	debugCmd.AddCommand(&debugInfoCmd)
}
