// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"context"
	"fmt"
	"os"

	"github.com/spf13/cobra"
)

var envelopePurgeCmd = &cobra.Command{
	Use:   "purge",
	Short: "Remove envelopes that are not in an existing process",
	Args:  cobra.NoArgs,
	Run: func(_ *cobra.Command, _ []string) {
		c, err := GetClient(false)
		if err != nil {
			return
		}
		ctx, _ := contextCancelOnSignal(
			context.Background(), os.Interrupt,
		)
		var count, scanned uint32
		fmt.Print("\nPurge: ")
		err = c.EnvelopePurge(
			ctx, func(c, m uint32) {
				fmt.Printf("\rPurge: %d (%d...)", c, m)
				count = c
				scanned = m
			},
		)
		fmt.Print("\r")
		if err != nil {
			Logger.Error().Msgf("%s", err)
			return
		}
		Logger.Info().Msgf("Purged %d envelope(s) out of %d", count, scanned)
	},
}

func init() {
	envelopeCmd.AddCommand(envelopePurgeCmd)
}
