// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"os"

	"github.com/spf13/cobra"
)

// keyGenerateCmd represents the key generation sub-command.
var keyGenerateCmd = &cobra.Command{
	Use:   "generate",
	Short: "Generate a private key.",
	Long:  "Generate a private key named based on the selected user.",
	Run:   generateKey,
}

// generateKey parses arguments to generate a private key.
func generateKey(_ *cobra.Command, _ []string) {
	os.Exit(doGenerateKey())
}

// doGenerateKey generates a private key  named based on the selected user.
func doGenerateKey() int {
	client, err := GetClient(false)
	if err != nil {
		Logger.Error().Msgf("%s", err)
		return 1
	}
	if err := client.CreateKey(false); err != nil {
		Logger.Error().Msgf("%s", err)
		return 1
	}
	Logger.Info().Msgf("Successfully generated a key.")
	return 0
}

func init() {
	keyCmd.AddCommand(keyGenerateCmd)
}
