// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"fmt"

	"github.com/spf13/cobra"
)

var logsStatCmd = &cobra.Command{
	Use:   "stat",
	Short: "Print stats of the log storage content",
	Args:  cobra.NoArgs,
	Run: func(_ *cobra.Command, _ []string) {
		c, err := GetClient(false)
		if err != nil {
			return
		}

		stat, err := c.Control.Logs.GetStorageStat()
		if err != nil {
			Logger.Error().Msgf("%s", err)
			return
		}

		fmt.Print(FmtStorageStat(stat))
	},
}

func init() {
	logsCmd.AddCommand(logsStatCmd)
}
