// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"context"
	"os"

	"github.com/olekukonko/tablewriter"
	"github.com/spf13/cobra"
	"xbus.io/go-xbus/v4/api"
)

var pmCmd = &cobra.Command{
	Use:   "pm",
	Short: "Postmortem process management",
	Run: func(_ *cobra.Command, _ []string) {
		c, err := GetClient(false)
		if err != nil {
			Logger.Error().Msgf("%s", err)
			os.Exit(1)
		}
		ctx, _ := contextCancelOnSignal(
			context.Background(), os.Interrupt,
		)
		list, err := c.PMProcessQuery(ctx, api.LogLevel_WARNING, false, []api.UUID{}, false)
		if err != nil {
			Logger.Error().Msgf("%s", err)
			os.Exit(1)
		}
		table := tablewriter.NewWriter(os.Stdout)
		table.SetHeader([]string{"id", "level", "status", "comment"})
		for _, p := range list {
			table.Append([]string{
				p.Process.GetIDAsUUID().String(),
				p.Level.String(),
				p.Status.String(),
				p.Comment,
			})
		}
		table.Render()
	},
}

func setStatus(processID api.UUID, status api.PMProcess_Status, comment string) int {
	c, err := GetClient(false)
	if err != nil {
		Logger.Error().Msgf("%s", err)
		return 1
	}
	if err := c.PMProcessSetStatus(processID, status, comment); err != nil {
		Logger.Error().Msgf("%s", err)
		return 1
	}
	return 0
}

func init() {
	RootCmd.AddCommand(pmCmd)
}
