// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package fullenv

import (
	"time"

	xbus "xbus.io/go-xbus/v4"
	"xbus.io/go-xbus/v4/api"
)

// NewEmitter initializes a Emitter
func NewEmitter() *Emitter {
	return &Emitter{}
}

// Emitter is an emitter actor for FullEnv
type Emitter struct {
	Actor *xbus.Actor
}

// Service is a Actor factory
func (e *Emitter) Service(actor *xbus.Actor, _ xbus.Settings) (xbus.ActorService, error) {
	e.Actor = actor
	return e, nil
}

// Startup ...
func (e *Emitter) Startup() error {
	return nil
}

// Shutdown ...
func (e *Emitter) Shutdown() error {
	return nil
}

// NewConsumer initializes a Consumer
func NewConsumer() *Consumer {
	return &Consumer{}
}

// Consumer is an emitter actor for FullEnv
type Consumer struct {
	Actor *xbus.Actor
	log   xbus.Logger

	Envelopes []*api.Envelope
}

// Service is a Actor factory
func (c *Consumer) Service(actor *xbus.Actor, _ xbus.Settings) (xbus.ActorService, error) {
	c.Actor = actor
	c.log = actor.Log
	return c, nil
}

// Process is called by xbus when inputs are ready
func (c *Consumer) Process(apc *xbus.ActorProcessingContext) error {
	env, err := apc.CompleteEnvelope(api.DefaultInput, time.Second)
	if err != nil {
		c.log.Error().Msgf("Error receiving envelope: %s", err)
		return err
	}
	c.Envelopes = append(c.Envelopes, env)
	if !c.Actor.Options.Service.Settings.MustBoolD("autosuccess", false) {
		apc.Detach()
	}
	return nil
}
