// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package pipeline

import (
	"fmt"
	"regexp"
)

// setEqual compare two slices of strings and return true if they contain
// the same elements no matter the order
// The sets must not contain twice the same element
func stringSetEqual(s1, s2 []string) bool {
	if len(s1) != len(s2) {
		return false
	}
	for _, v1 := range s1 {
		found := false
		for _, v2 := range s2 {
			if v1 == v2 {
				found = true
				break
			}
		}
		if !found {
			return false
		}
	}
	return true
}

func matchEventTypesRe(exp string, eventtypes []string) (bool, error) {
	r, err := regexp.Compile(exp)
	if err != nil {
		return false, err
	}
	for _, eventtype := range eventtypes {
		if !r.Match([]byte(eventtype)) {
			return false, nil
		}
	}
	return true, nil
}

func MatchEventTypes(match []string, eventtypes []string) bool {
	if len(match) > 1 && match[0] == "match:regexp" {
		if len(match) != 2 {
			panic(fmt.Errorf("match:regexp expect a single arg. Got %d", len(match)-1))
		}
		res, err := matchEventTypesRe(match[1], eventtypes)
		if err != nil {
			panic(err)
		}
		return res
	}
	return stringSetEqual(match, eventtypes)
}
