// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package director

import (
	"testing"

	"github.com/stretchr/testify/assert"
	"xbus.io/go-xbus/v4/api"
)

func TestEnvelopeWatcher(t *testing.T) {
	watcher := NewEnvelopeWatcher()

	var (
		id1    = api.MustUUIDFromString("c2ecca92-f6da-11e8-8087-3f6da02fa340")
		event1 = &api.EnvelopeEvent{
			EnvelopeID: id1.ToBytes(),
			Status:     api.EnvelopeEvent_RECEIVING,
			NewData:    true,
		}
		id2    = api.MustUUIDFromString("f6769eb0-f6da-11e8-ab4f-2fa6c7d52270")
		event2 = &api.EnvelopeEvent{
			EnvelopeID: id2.ToBytes(),
			Status:     api.EnvelopeEvent_COMPLETE,
			NewData:    false,
		}
		id3    = api.MustUUIDFromString("f724ad7a-f6da-11e8-bf60-e7da1dbf3d4d")
		event3 = &api.EnvelopeEvent{
			EnvelopeID: id3.ToBytes(),
			Status:     api.EnvelopeEvent_ERROR,
			NewData:    false,
		}

		h1hit bool
		h2hit bool
		h3hit bool
	)

	watcher.PushEvent(event1)

	h1 := func(_ *api.EnvelopeEvent) {
		h1hit = true
	}

	h2 := func(_ *api.EnvelopeEvent) {
		h2hit = true
	}

	h3 := func(_ *api.EnvelopeEvent) {
		h3hit = true
	}

	s1 := watcher.Watch(h1, id1)
	defer s1.Unsubscribe()
	s2 := watcher.Watch(h2, id1, id2)
	defer s2.Unsubscribe()
	s3 := watcher.Watch(h3, id2, id3)
	defer s3.Unsubscribe()

	watcher.PushEvent(event1)
	assert.True(t, h1hit)
	assert.True(t, h2hit)
	assert.False(t, h3hit)
	h1hit = false
	h2hit = false
	h3hit = false

	watcher.PushEvent(event2)
	assert.False(t, h1hit)
	assert.True(t, h2hit)
	assert.True(t, h3hit)
	h1hit = false
	h2hit = false
	h3hit = false

	watcher.PushEvent(event3)
	assert.False(t, h1hit)
	assert.False(t, h2hit)
	assert.True(t, h3hit)
	h1hit = false
	h2hit = false
	h3hit = false

	s3.Unsubscribe()

	watcher.PushEvent(event2)
	assert.False(t, h1hit)
	assert.True(t, h2hit)
	assert.False(t, h3hit)
	h1hit = false
	h2hit = false
	h3hit = false
}
