// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package storage

import (
	jsoniter "github.com/json-iterator/go"
	"xbus.io/go-xbus/v4/utils"
)

func (p EnvelopeReadPos) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	defer obj.End()

	obj.Bool("start", p.Start)
	obj.Bool("complete", p.Complete)

	if len(p.Events) != 0 {
		eventsObj := obj.Object("events")
		for id, event := range p.Events {
			eventsObj.Val(id.String(), event)
		}
		eventsObj.End()
	}
}

func (p EventReadPos) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	defer obj.End()

	obj.Uint64("index", p.Index)
	obj.Uint64("item_count", p.ItemCount)
}
