// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package storage

import (
	jsoniter "github.com/json-iterator/go"
	"xbus.io/go-xbus/v4/utils"
)

func (m Job) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	defer obj.End()

	if !m.ProcessID.IsZero() {
		obj.Val("process_id", m.ProcessID)
	}

	obj.OEString("node", m.Node.String())
	obj.TimeOE("created_at", m.CreatedAt)
	obj.OEBool("detached", m.Detached)
	obj.String("status", m.Status.String())
	if len(m.EnvelopeIDs) != 0 {
		a := obj.Array("envelope_ids")
		for _, id := range m.EnvelopeIDs {
			a.Val(id)
		}
		a.End()
	}

	obj.TimeOE("first_attempt", m.FirstAttempt)
	obj.OEUint("attempt_count", m.AttemptCount)
}
