// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package storage

import (
	jsoniter "github.com/json-iterator/go"
	"xbus.io/go-xbus/v4/utils"
)

func (s PostMortemState) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	obj.OEString("level", s.Level.String())
	obj.OEString("status", s.Status.String())
	obj.OEString("comment", s.Comment)
	obj.TimeOE("changed", s.Changed)
	obj.End()
}

func (s ProcessState) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	obj.OEString("status", s.Status.String())
	obj.TimeOE("status_changed", s.StatusChanged)
	obj.OEString("status_reason", s.StatusReason)
	obj.Val("response_envelope_id", s.ResponseEnvelopeID)
	obj.OEBool("result_acked", s.ResultAcked)
	obj.TimeOE("node_states_changed", s.NodeStatesChanged)
	if len(s.NodeStates) != 0 {
		obj.Val("node_states", s.NodeStates)
	}
	obj.End()
}

func (m ProcessNodeStateMap) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	for id, state := range m {
		obj.Val(id.String(), state)
	}
	obj.End()
}

func (m ProcessNodeState) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	obj.Val("status", m.Status)
	obj.OEString("error", m.Error)
	obj.Val("input", m.Input)
	obj.Val("output", m.Output)
	if len(m.InputStatuses) != 0 {
		obj.Val("input_statuses", m.InputStatuses)
	}
	if len(m.OutputStatuses) != 0 {
		obj.Val("output_statuses", m.OutputStatuses)
	}
	obj.End()
}

func (e ProcessLogEntry) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	defer obj.End()

	obj.OEString("id", e.ID)
	if !e.ProcessID.IsZero() {
		obj.Val("process_id", e.ProcessID)
	}
	obj.TimeOE("timestamp", e.Timestamp)
	if e.Emission != nil {
		obj.Val("emission", e.Emission)
	}
	if e.EmissionPosition != nil {
		obj.Val("emission_position", e.EmissionPosition)
	}
	if e.Reception != nil {
		obj.Val("reception", e.Reception)
	}
	obj.String("reception_status", e.ReceptionStatus.String())
	if e.ProcessNodeEnd != nil {
		obj.Val("process_node_end", e.ProcessNodeEnd)
	}
	obj.OEBool("result_ack", e.ResultAck)
}

func (e Emission) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)
	defer obj.End()

	if id := e.ProcessID; !id.IsZero() {
		obj.String("process_id", id.String())
	}
	if id := e.EnvelopeID; !id.IsZero() {
		obj.String("envelope_id", id.String())
	}
	if id := e.TargetActor; !id.IsZero() {
		obj.String("target_actor", id.String())
	}
	obj.String("target_input_ref", e.TargetInputRef.String())
}
