// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package storage

import (
	"context"
	"time"

	"xbus.io/go-xbus/v4/api"
)

// Session links a SessionToken and a Account
type Session struct {
	*api.SessionToken
	AccountID api.UUID
}

// SessionStorage stores Sessions
type SessionStorage interface {
	List(context.Context) ([]Session, error)
	Get(ctx context.Context, token string) (*Session, error)
	Set(context.Context, Session) error
	Delete(ctx context.Context, token string) error
	DeleteOlderThan(ctx context.Context, time time.Time) error
}
