// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package model

import (
	"encoding/json"
	"time"

	"github.com/m4rw3r/uuid"
	"xbus.io/go-xbus/v4/api"
)

//go:generate yago --fmt

// Actor is any client of the bus (emitter, consumer, worker)
// yago:
type Actor struct {
	Base
	Name      string           `yago:"unique_index=name"`
	AccountID uuid.NullUUID    `yago:"fk=Account ONDELETE SET NULL"`
	Kind      api.Actor_Kind   `yago:"textmarshaled"`
	Role      string           `yago:"."`
	Status    api.Actor_Status `yago:"textmarshaled"`

	Online       bool      `yago:"."`
	Unresponsive bool      `yago:"."`
	LastSeen     time.Time `yago:"."`

	Config string `yago:"."`
}

// ToAPI convert the actor to a api.Actor
func (a Actor) ToAPI() *api.Actor {
	actor := api.Actor{
		ID:     api.UUID(a.ID).ToBytes(),
		Name:   a.Name,
		Kind:   a.Kind,
		Roles:  []string{a.Role},
		Status: a.Status,
	}
	if a.Config != "" {
		if err := json.Unmarshal([]byte(a.Config), &actor.Config); err != nil {
			panic(err)
		}
	}
	return &actor
}

// ActorListToAPI converts a []Actor to []api.Actor
func ActorListToAPI(actors []Actor) (res []*api.Actor) {
	for _, a := range actors {
		res = append(res, a.ToAPI())
	}
	return
}
