// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package testutils

import (
	"encoding/json"

	"github.com/stretchr/testify/assert"
	"xbus.io/go-xbus/v4/testutils"
)

// TestLogger is a proxy to go-xbus/testutils.TestLogger
type TestLogger = testutils.TestLogger

var (
	// GetTestLogger is a proxy to go-xbus/testutils.GetTestLogger
	GetTestLogger = testutils.GetTestLogger
	// ExpectsEqual is a proxy to go-xbus/testutils.ExpectsEqual
	ExpectsEqual = testutils.ExpectsEqual
	// ExpectsContains is a proxy to go-xbus/testutils.ExpectsContains
	ExpectsContains = testutils.ExpectsContains
)

// ExpectsJSONContains match
func ExpectsJSONContains(expected interface{}) testutils.ExpectedError {
	var b []byte
	if v, ok := expected.(string); ok {
		b = []byte(v)
	} else if v, ok := expected.([]byte); ok {
		b = v
	} else {
		var err error
		b, err = json.Marshal(expected)
		if err != nil {
			panic(err)
		}
	}
	var expectedAsMap map[string]interface{}
	if err := json.Unmarshal(b, &expectedAsMap); err != nil {
		panic(err)
	}
	return testutils.ExpectedError{
		Name: string(b),
		MatchMessage: func(text string) bool {
			var asMap map[string]interface{}
			if err := json.Unmarshal([]byte(text), &asMap); err != nil {
				return false
			}
			for k, expectedValue := range expectedAsMap {
				if value, ok := asMap[k]; ok {
					if !assert.ObjectsAreEqual(expectedValue, value) {
						return false
					}
				} else {
					return false
				}
			}
			return true
		},
	}
}
