// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package utils

import (
	"context"
	"errors"
	"fmt"
	"strings"
)

func CombineErrors(msg string, errs ...error) error {
	var (
		nonNilErrs = make([]interface{}, 0, len(errs))
		fmtList    = make([]string, 0, len(errs))
	)
	for _, err := range errs {
		if err != nil && !errors.Is(err, context.Canceled) {
			nonNilErrs = append(nonNilErrs, err)
			fmtList = append(fmtList, "%w")
		}
	}
	if len(nonNilErrs) != 0 {
		return fmt.Errorf(msg+strings.Join(fmtList, ", "), nonNilErrs...)
	}
	return nil
}
